@@ -4,7 +4,7 @@ Miscellaneous utilities
 
 import importlib
 
-from typing import Union, Callable, Type
+from typing import Union, Callable, Type, Dict
 
 from .exception import ProcException
 
@@ -20,3 +20,10 @@ def import_object(objname: str) -> Union[Callable, Type]:
         return getattr(mod, oname)
     except Exception as e:
         raise ProcException("cannot import object '{}': {}", objname, e) from e
+
+
+def filter_dict(d: Dict) -> Dict:
+    """
+    Return a streamlined version of a dict, without the `None` valued fields
+    """
+    return {k: v for k, v in d.items() if v is not None}
